# Global Meth Package

Библиотека методов глобальной оптимизации, включающая пять реализаций:
 - Метод ветвей и границ с оценкой Липшица
 - Сеточный поиск
 - Метод Монте-Карло
 - Метод имитации отжига
 - Генетический алгоритм

## Установка

Рекомендуется использовать виртуальное окружение.

'''bash
pip install -e ".[dev]"

## Использование

Импортировать нужный метод из пакета можно по примеру:
 from global_meth_package.branch_and_bound import branch_and_bound
 from global_meth_package.utils import rastrigin
 
 bounds = [(-5.12, 5.12)] * 3
 L = 126  # оценка Липшица
 x, fx = branch_and_bound(rastrigin, bounds, L)
 print(f"Приближённый глобальный минимум найден в точке: {x}, значение функции в ней: {fx}")

## Тестирование

Запустить тесты можно командой pytest.